========
Plotters
========

Create figures and subplots of non-linear search specific visualization of every search algorithm supported
by **PyAutoFit**.

**Examples / Tutorials:**

- `readthedocs: non-linear search example <https://pyautofit.readthedocs.io/en/latest/overview/non_linear_search.html>`_
- `autofit_workspace: plot tutorials <https://github.com/Jammy2211/autofit_workspace/tree/release/notebooks/plot>`_
- `HowToFit: introduction chapter (detailed step-by-step examples) <https://pyautofit.readthedocs.io/en/latest/howtofit/chapter_1_introduction.html>`_

--------
Plotters
--------

.. currentmodule:: autofit.plot

.. autosummary::
   :toctree: _autosummary
   :template: custom-class-template.rst
   :recursive:

   DynestyPlotter
   UltraNestPlotter
   EmceePlotter
   ZeusPlotter
   PySwarmsPlotter